tonalitytools.InversionIndicator
================================

.. inheritance-diagram:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.name

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.number

.. autoattribute:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.title

Methods
-------

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.extent_to_figured_bass_string

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__eq__

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__ne__

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__repr__

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tonalitytools.InversionIndicator.InversionIndicator.InversionIndicator.__str__

   .. note:: Inherited from `__builtin__.object`
